==> haskell-hspec-hedgehog-0.0.1.2-254-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-LkDGPwY4vRkJWDm5HfKpuE
key:                  hspec-hedgehog-0.0.1.2-LkDGPwY4vRkJWDm5HfKpuE
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  4c0344e1b58dfef70b274b0dd74664ca
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-LkDGPwY4vRkJWDm5HfKpuE
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    QuickCheck-2.14.3-FZiRXTXSsGZ9xX5Wd8RRwa base-4.16.4.0
    hedgehog-1.2-4lht0I6z8ZrBZVgU5NLtxb
    hspec-2.10.9-Dvy7WR1iRTQAyVGgNCfLMg
    hspec-core-2.10.9-Kj9G7Zg2qINCYrDLS3t3qJ
    splitmix-0.1.0.5-5h8if16T4XgGUkGyuip3fZ

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-hedgehog-0.0.1.2-255-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-IW5UogNby5a1NopL3OhwsU
key:                  hspec-hedgehog-0.0.1.2-IW5UogNby5a1NopL3OhwsU
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  1abf904029be2e0530c1199c9d872a92
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-hedgehog
hs-libraries:         HShspec-hedgehog-0.0.1.2-IW5UogNby5a1NopL3OhwsU
depends:
    HUnit-1.6.2.0-5hykmsvl02FAiEpCakZNiG
    QuickCheck-2.14.3-2fwOGp9PorUAao68q5lrRL base-4.16.4.0
    hedgehog-1.2-FeQN19ytYBKAvSuURtrZdH
    hspec-2.10.9-2BmqnW2Fk1DIXcHb46YxpU
    hspec-core-2.10.9-7mrWwh8meI8InzvMrV3617
    splitmix-0.1.0.5-Ejf5mOuYhfy7Y0tfyAQ8Dy

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
